@@ -247,7 +247,7 @@ class RuleSetExpandingShorthandTests < Minitest::Test
       'list-style-position' => 'inside'
     }
 
-    shorthand = "list-style: katakana inside url(\'chess.png\');"
+    shorthand = "list-style: katakana inside url('chess.png');"
     declarations = expand_declarations(shorthand)
     assert_equal expected, declarations
   end
@@ -347,7 +347,7 @@ class RuleSetExpandingShorthandTests < Minitest::Test
 protected
 
   def expand_declarations(declarations)
-    ruleset = RuleSet.new(nil, declarations)
+    ruleset = RuleSet.new(block: declarations)
     ruleset.expand_shorthand!
 
     collected = {}
